==> nanoc_4.8.0.orig.tar.gz: nanoc-4.8.0/lib/nanoc/base/services/compiler/stages/compile_reps.rb <==
# frozen_string_literal: true

module Nanoc::Int::Compiler::Stages
  class CompileReps
    def initialize(outdatedness_store:, dependency_store:, action_sequences:, compilation_context:, compiled_content_cache:)
      @outdatedness_store = outdatedness_store
      @dependency_store = dependency_store
      @action_sequences = action_sequences
      @compilation_context = compilation_context
      @compiled_content_cache = compiled_content_cache
    end

    def run
      selector = Nanoc::Int::ItemRepSelector.new(@outdatedness_store.to_a)
      selector.each do |rep|
        handle_errors_while(rep) { compile_rep(rep, is_outdated: @outdatedness_store.include?(rep)) }
      end
    ensure
      @outdatedness_store.store
      @compiled_content_cache.store
    end

    private

    def handle_errors_while(item_rep)
      yield
    rescue => e
      raise Nanoc::Int::Errors::CompilationError.new(e, item_rep)
    end

    def compile_rep(rep, is_outdated:)
      item_rep_compiler.call(rep, is_outdated: is_outdated)
    end

    def item_rep_compiler
      @_item_rep_compiler ||= begin
        recalculate_phase = Nanoc::Int::Compiler::Phases::Recalculate.new(
          action_sequences: @action_sequences,
          dependency_store: @dependency_store,
          compilation_context: @compilation_context,
        )

        cache_phase = Nanoc::Int::Compiler::Phases::Cache.new(
          compiled_content_cache: @compiled_content_cache,
          snapshot_repo: @compilation_context.snapshot_repo,
          wrapped: recalculate_phase,
        )

        resume_phase = Nanoc::Int::Compiler::Phases::Resume.new(
          wrapped: cache_phase,
        )

        write_phase = Nanoc::Int::Compiler::Phases::Write.new(
          snapshot_repo: @compilation_context.snapshot_repo,
          wrapped: resume_phase,
        )

        mark_done_phase = Nanoc::Int::Compiler::Phases::MarkDone.new(
          wrapped: write_phase,
          outdatedness_store: @outdatedness_store,
        )

        mark_done_phase
      end
    end
  end
end

==> nanoc_4.8.10.orig.tar.gz: nanoc-4.8.10/lib/nanoc/base/services/compiler/stages/compile_reps.rb <==
# frozen_string_literal: true

module Nanoc::Int::Compiler::Stages
  class CompileReps
    def initialize(reps:, outdatedness_store:, dependency_store:, action_sequences:, compilation_context:, compiled_content_cache:)
      @reps = reps
      @outdatedness_store = outdatedness_store
      @dependency_store = dependency_store
      @action_sequences = action_sequences
      @compilation_context = compilation_context
      @compiled_content_cache = compiled_content_cache
    end

    def run
      outdated_reps = @reps.select { |r| @outdatedness_store.include?(r) }
      selector = Nanoc::Int::ItemRepSelector.new(outdated_reps)
      selector.each do |rep|
        handle_errors_while(rep) { compile_rep(rep, is_outdated: @outdatedness_store.include?(rep)) }
      end
    ensure
      @outdatedness_store.store
      @compiled_content_cache.store
    end

    private

    def handle_errors_while(item_rep)
      yield
    rescue => e
      raise Nanoc::Int::Errors::CompilationError.new(e, item_rep)
    end

    def compile_rep(rep, is_outdated:)
      item_rep_compiler.call(rep, is_outdated: is_outdated)
    end

    def item_rep_compiler
      @_item_rep_compiler ||= begin
        recalculate_phase = Nanoc::Int::Compiler::Phases::Recalculate.new(
          action_sequences: @action_sequences,
          dependency_store: @dependency_store,
          compilation_context: @compilation_context,
        )

        cache_phase = Nanoc::Int::Compiler::Phases::Cache.new(
          compiled_content_cache: @compiled_content_cache,
          snapshot_repo: @compilation_context.snapshot_repo,
          wrapped: recalculate_phase,
        )

        resume_phase = Nanoc::Int::Compiler::Phases::Resume.new(
          wrapped: cache_phase,
        )

        write_phase = Nanoc::Int::Compiler::Phases::Write.new(
          snapshot_repo: @compilation_context.snapshot_repo,
          wrapped: resume_phase,
        )

        mark_done_phase = Nanoc::Int::Compiler::Phases::MarkDone.new(
          wrapped: write_phase,
          outdatedness_store: @outdatedness_store,
        )

        mark_done_phase
      end
    end
  end
end
